@@ -6,6 +6,7 @@
 # the enclosed file COPYING for license information (GPL). If you
 # did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
 # --
+## nofilter(TidyAll::Plugin::Znuny::CodeStyle::STDERRCheck)
 
 package Kernel::System::Console::BaseCommand;
 
@@ -909,8 +910,12 @@ sub _ParseCommandlineArguments {
 
     my %OptionValues;
 
+    my %KnownOptions;
+
     OPTION:
     for my $Option ( @{ $Self->{_Options} // [] }, @{ $Self->{_GlobalOptions} } ) {
+        $KnownOptions{ '--' . $Option->{Name} } = 1;
+
         my $Lookup = $Option->{Name};
         if ( $Option->{HasValue} ) {
             $Lookup .= '=s';
@@ -976,6 +981,14 @@ sub _ParseCommandlineArguments {
         }
     }
 
+    # Check for remaining known options that could not be parsed.
+    my @RemainingKnownOptions = grep { exists $KnownOptions{$_} } @{$Arguments};
+    if (@RemainingKnownOptions) {
+        my $OptionsString = join ', ', sort @RemainingKnownOptions;
+        $Self->PrintError("the following options have an unexpected or missing value: $OptionsString.");
+        return;
+    }
+
     my %ArgumentValues;
 
     ARGUMENT:
